@@ -1,5 +1,5 @@
 package Finance::Shares::lowest;
-our $VERSION = 1.01;
+our $VERSION = 1.03;
 use strict;
 use warnings;
 use Finance::Shares::Support qw(%period out show $highest_int);
@@ -52,7 +52,7 @@ sub build {
 	my $high = lowest( $values, $o->{period}, $i );
 	$points[$i] = $high if defined $high;
     }
-    my $l = $o->line('low');
+    my $l = $o->func_line('low');
     $l->{data} = \@points;
 
     unless ($l->{key}) {
@@ -156,7 +156,7 @@ default)
 
 Required, unless B<graph> is given.  This specifies the type of graph the function
 lines should appear on.  It should be one of C<price>, C<volume>, C<analysis> or
-C<level>.  (Default: C<price>)
+C<logic>.  (Default: C<price>)
 
 =head3 line
 
