@@ -1,5 +1,5 @@
 package Finance::Shares::weighted_average;
-our $VERSION = 1.01;
+our $VERSION = 1.03;
 use strict;
 use warnings;
 use Finance::Shares::Support qw(%period out show);
@@ -48,7 +48,7 @@ sub build {
     for (my $i = 0; $i <= $#$d; $i++) {
 	push @points, $o->weighted_average($v, $i);
     }
-    my $l = $o->line('line');
+    my $l = $o->func_line('line');
     $l->{data} = \@points;
 	
     unless ($l->{key}) {
@@ -154,7 +154,7 @@ default)
 
 Required, unless B<graph> is given.  This specifies the type of graph the function
 lines should appear on.  It should be one of C<price>, C<volume>, C<analysis> or
-C<level>.  (Default: C<price>)
+C<logic>.  (Default: C<price>)
 
 =head3 line
 
